A Java library that wraps JavaScript code and allows generating JavaScript source files from Java JavaScript-methods.

Download latest version
========================================

https://github.com/corgrath/Java-JavaScript-Wrapper/downloads/

Quick guide
========================================

Basic JavaScript usage
--------------------------------------------------------------------------------

	JavaScript myAlertBox = new JavaScript("alert('Hello world!');");
	
	System.out.println( "<button type=\"button\" onclick=\"" + myAlertBox + "\">Click Me!</button>" );
	
Which outputs:

	<button type="button" onclick="alert('Hello world!');">Click Me!</button>

Different output types
--------------------------------------------------------------------------------

	JavaScript myAlertBox = new JavaScript("alert(\"Hello world!\");");
	
	System.out.println( myAlertBox.toString(TYPE.DOWNGRADE) );
	
Which outputs: alert('Hello world!');

	System.out.println( myAlertBox.toString(TYPE.ESCAPED) );
	
Which outputs: alert(&amp;quot;Hello world!&amp;quot;);


Basic JavaScriptFunction usage
--------------------------------------------------------------------------------

### 1 Declare a static method that returns a JavaScript object

	public class MyFunctions {

		public static JavaScript showGreeting( final String firstname, final String surname ) {
			
			return new JavaScript("$test", "alert('Hello %s %s!');", firstname, surname);
			
		} 
		 
	}	
	
### 2 Add the JavaScriptFunction annotation

	public class MyFunctions {

		@JavaScriptFunction
		public static JavaScript showGreeting( final String firstname, final String surname ) {
			
			return new JavaScript("$test", "alert('Hello %s %s!');", firstname, surname);
			
		}
	 
	}
	
### 3 Create a generator

	public final class MyGenerator {
	
		public static void main(String[] args) throws Exception {
	
			List<Class<?>> classes = new ArrayList<Class<?>>();
	
			classes.add(MyFunctions.class);
	
			File javaScriptFile = new File("/javascript.js");
	
			Generator.generateTo(classes, javaScriptFile, true);
	
		}
	
	}

### 4 Run the generator

The generator generates a JavaScript source file (in this case javascript.js):
	
	/*
	 * Object structures
	 */
	
	function $test() {
	}
	
	/*
	 * MyFunctions.showGreeting
	 */
	
	$test.b0a2a47a18f9307be3e30b18d6c2f10c = function($0$, $1$) {
		alert('Hello ' + $0$ + ' ' + $1$ + '!');
	}

### 5 Calling the function

	JavaScript greetingCode = MyFunctions.showGreeting( "John", "Doe" );
	
	System.out.println( "<button type=\"button\" onclick=\"" + greetingCode.call() + "\">Click Me!</button>" );
	
Which outputs:

	<button type="button" onclick="$test.b0a2a47a18f9307be3e30b18d6c2f10c( 'John', 'Doe' );">Click Me!</button>


JavaDoc
========================================

http://dl.dropbox.com/u/8183146/persistent/projects/java_javascript_wrapper/javadoc/index.html


Changes
========================================

v1.2 2011-08-21 Christoffer Pettersson

* JavaScript is now Serializable

v1.1 2011-08-07 Christoffer Pettersson

 * Added JavaScriptFunction feature

v1.0 2011-07-17 Christoffer Pettersson

 * Initial release


License
========================================

Java JavaScript Wrapper - Copyright 2011 Christoffer Pettersson, christoffer@christoffer.me

Licensed under the Apache License, Version 2.0