/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 */

package com.osbcp.apbs.annotations;

import java.util.List;

import javax.lang.model.type.TypeMirror;

/**
 * Container class for method data extracted by the Annotation Processing Tool
 * 
 * @author <a href="mailto:christoffer@christoffer.me">Christoffer Pettersson</a>
 */

final class MethodData {

	private TypeMirror returnType;
	private List<? extends TypeMirror> parameterTypes;

	/**
	 * Sets the method parameter types.
	 * 
	 * @param parameterTypes The method parameter types.
	 */

	final void setParameterTypes(final List<? extends TypeMirror> parameterTypes) {
		this.parameterTypes = parameterTypes;
	}

	/**
	 * Returns the method parameter types.
	 * 
	 * @return The method parameter types.
	 */

	final List<? extends TypeMirror> getParameterTypes() {
		return parameterTypes;
	}

	/**
	 * Returns the method return type.
	 * 
	 * @return The method return type.
	 */

	final TypeMirror getReturnType() {
		return returnType;
	}

	/**
	 * Sets the method return type.
	 * 
	 * @param returnType The method return type
	 */

	final void setReturnType(final TypeMirror returnType) {
		this.returnType = returnType;
	}

}