/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 */

package com.osbcp.apbs.annotations;

import java.util.Arrays;
import java.util.List;

/**
 * Utility class for String methods.
 * 
 * @author <a href="mailto:christoffer@christoffer.me">Christoffer Pettersson</a>
 */

final class StringUtil {

	/**
	 * Takes in an array of Objects and returns a comma String separated list
	 * 
	 * @param array An array of Objects
	 * @return A comma separated String
	 */

	final static String toString(final Object[] array) {
		return toString(Arrays.asList(array));
	}

	/**
	 * Takes in an array an List of Objects and returns a comma String separated list
	 * 
	 * @param list An array of Objects
	 * @return A comma separated String
	 */

	final static String toString(final List<?> list) {

		StringBuilder output = new StringBuilder();

		for (int i = 0; i < list.size(); i++) {

			Object object = list.get(i);

			output.append(object.toString());

			if (i < (list.size() - 1)) {
				output.append(", ");
			}

		}

		return output.toString().trim();

	}

}