/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 */

package com.osbcp.apbs.events;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;

import com.osbcp.jjsw.JavaScript;

/**
 * An ajax post back event
 * 
 * @author <a href="mailto:christoffer@christoffer.me">Christoffer Pettersson</a>
 */

public abstract class AjaxPostBackEvent {

	private Map<Serializable, Object> metaData = new HashMap<Serializable, Object>();

	/**
	 * Returns a JavaScript response that should be performed by the browser.
	 * 
	 * @return A JavaScript response that should be performed by the browser.
	 */

	public abstract JavaScript getJavaScriptResponse();

	/**
	 * Returns a map of meta data included in the event, defined in the AjaxPostBackServlet.
	 * 
	 * @param key A unique key in the map.
	 * @return The meta data object associated with the key.
	 */

	public Object getMetaData(final Serializable key) {
		return metaData.get(key);
	}

	/**
	 * Sets a specific meta data object associated with a unique key.
	 * 
	 * @param metaData The meta data object.
	 */

	public void setMetaData(final Map<Serializable, Object> metaData) {
		this.metaData = metaData;
	}

}