/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 */

package com.osbcp.jjsw;

/**
 * Utility class for Class methods.
 * 
 * @author <a href=\"mailto:christoffer@christoffer.me\">Christoffer Pettersson</a>
 */

final class ClassUtil {

	/**
	 * Returns a list of predefined objects based on different types.
	 * 
	 * @param types The class types of the parameters
	 * @return A list of predefined objects based on different types
	 * @throws Exception If any error occurs
	 */

	final static Object[] getPreDefinedParametersByTypes(final Class<?>[] types) throws Exception {

		Object[] randomValues = new Object[types.length];

		for (int i = 0; i < randomValues.length; i++) {

			if (types[i] == String.class) {
				randomValues[i] = new String("");
			} else if (types[i] == Boolean.class || types[i] == Boolean.TYPE) {
				randomValues[i] = new Boolean(true);
			} else if (types[i] == Integer.class || types[i] == Integer.TYPE) {
				randomValues[i] = new Integer(0);
			} else if (types[i] == Double.class || types[i] == Double.TYPE) {
				randomValues[i] = new Double(0);
			} else {
				throw new Exception("Illegal type '" + types[i].getCanonicalName() + "'. If this was a primitive type (eg boolean), the class version (eg Boolean) should be used instead.");
			}

		}

		return randomValues;
	}

}